@@ -131,7 +131,8 @@ def get_connection_tunnel(conf):
         ssh_address_or_host=(conf.get('ssh_host'), int(conf.get('ssh_port'))),
         ssh_username=conf.get('ssh_user'),
         ssh_pkey=private_key,
-        remote_bind_address=(conf.get('host'), int(conf.get('port')))
+        remote_bind_address=(conf.get('host'), int(conf.get('port'))),
+        logger=logger
     )
     server.start()
 
@@ -229,7 +230,8 @@ def connect_database(conf):
             'MappedBase': MappedBase,
             'params_id': connection_params_id,
             'type_code_to_sql_type': type_code_to_sql_type,
-            'tunnel': tunnel
+            'tunnel': tunnel,
+            'cache': {}
         }
 
     session.close()
@@ -348,25 +350,57 @@ def get_type_code_to_sql_type(request):
     return connection['type_code_to_sql_type']
 
 
+def connection_cache_get(request, name, default=None):
+    connection = get_request_connection(request)
+    if not connection:
+        return
+    return connection['cache'].get(name, default)
+
+
+def connection_cache_set(request, name, value):
+    connection = get_request_connection(request)
+    if not connection:
+        return
+    connection['cache'][name] = value
+
+
+def reload_request_mapped_base(request):
+    MappedBase = get_mapped_base(request)
+    reload_mapped_base(MappedBase)
+    connection_cache_set(request, 'graphql_schema', None)
+
+
 def reload_mapped_base(MappedBase):
     def name_for_scalar_relationship(base, local_cls, referred_cls, constraint):
-        rnd = get_random_string(4)
-        return referred_cls.__name__.lower() + '_jet_relation' + rnd
+        foreign_key = constraint.elements[0] if len(constraint.elements) else None
+        if foreign_key:
+            name = '__'.join([foreign_key.parent.name, 'to', foreign_key.column.name])
+        else:
+            name = referred_cls.__name__.lower()
+
+        if name in constraint.parent.columns:
+            name = name + '_relation'
+            logger.warning("Already detected column name, using {}".format(name))
+
+        return name
 
     def name_for_collection_relationship(base, local_cls, referred_cls, constraint):
-        rnd = get_random_string(4)
-        return referred_cls.__name__.lower() + '_jet_collection' + rnd
+        foreign_key = constraint.elements[0] if len(constraint.elements) else None
+        if foreign_key:
+            name = '__'.join([foreign_key.parent.table.name, foreign_key.parent.name, 'to', foreign_key.column.name])
+        else:
+            name = referred_cls.__name__.lower()
 
-    def custom_generate_relationship(base, direction, return_fn, attrname, local_cls, referred_cls, **kw):
-        rnd = get_random_string(4)
-        attrname = attrname + '_jet_ref' + rnd
-        return generate_relationship(base, direction, return_fn, attrname, local_cls, referred_cls, **kw)
+        if name in constraint.parent.columns:
+            name = name + '_relation'
+            logger.warning("Already detected column name, using {}".format(name))
+
+        return name
 
     MappedBase.classes.clear()
     MappedBase.prepare(
         name_for_scalar_relationship=name_for_scalar_relationship,
-        name_for_collection_relationship=name_for_collection_relationship,
-        generate_relationship=custom_generate_relationship
+        name_for_collection_relationship=name_for_collection_relationship
     )
 
 
