@@ -15,6 +15,10 @@ class Request(object):
 
     session = None
     bridge_settings = None
+    project = None
+    environment = None
+    resource_token = None
+    context = {}
 
     def __init__(
             self,
