@@ -21,6 +21,7 @@ map_data_types = [
     {'sql_type': sqltypes.DateTime, 'map_type': data_types.DATE_TIME, 'db_type': data_types.DATE_TIME},
     {'sql_type': sqltypes.TIMESTAMP, 'map_type': data_types.DATE_TIME, 'db_type': data_types.TIMESTAMP},
     {'sql_type': sqltypes.JSON, 'map_type': data_types.JSON, 'db_type': data_types.JSON},
+    {'sql_type': sqltypes.ARRAY, 'map_type': data_types.JSON, 'db_type': data_types.JSON},
 ]
 default_sql_type = sqltypes.VARCHAR
 default_map_type = data_types.CHAR
@@ -35,6 +36,7 @@ except ImportError:
 
 try:
     from sqlalchemy.dialects import postgresql
+    map_data_types.append({'sql_type': postgresql.UUID, 'map_type': data_types.UUID, 'db_type': data_types.UUID})
     map_data_types.append({'sql_type': postgresql.DOUBLE_PRECISION, 'map_type': data_types.FLOAT, 'db_type': data_types.DOUBLE_PRECISION})
 except ImportError:
     pass
