@@ -1,15 +1,24 @@
 from jet_bridge_base import status
 from jet_bridge_base.configuration import configuration
 from jet_bridge_base.responses.json import JSONResponse
+from jet_bridge_base.utils.track_database import track_database_async
+from jet_bridge_base.utils.track_model import track_model_async
 
 
 class CreateAPIViewMixin(object):
 
     def create(self, request, *args, **kwargs):
+        track_database_async(request)
+
+        self.apply_timezone(request)
         serializer = self.get_serializer(request, data=request.data)
         serializer.is_valid(raise_exception=True)
         self.perform_create(request, serializer)
-        return JSONResponse(serializer.representation_data, status=status.HTTP_201_CREATED)
+
+        representation_data = serializer.representation_data
+        track_model_async(request, kwargs.get('model'), 'create', None, representation_data)
+
+        return JSONResponse(representation_data, status=status.HTTP_201_CREATED)
 
     def perform_create(self, request, serializer):
         serializer_instance = serializer.create_instance(serializer.validated_data)
