@@ -1,6 +1,7 @@
 import re
 
-from sqlalchemy import inspect, String, Enum
+from sqlalchemy import inspect, String, Enum, Date
+from sqlalchemy.orm import ONETOMANY
 from sqlalchemy.sql.elements import TextClause
 
 from jet_bridge_base.db import get_mapped_base
@@ -8,11 +9,15 @@ from jet_bridge_base.models import data_types
 from jet_bridge_base.permissions import HasProjectPermissions
 from jet_bridge_base.responses.json import JSONResponse
 from jet_bridge_base.serializers.model_description import ModelDescriptionSerializer
-from jet_bridge_base.utils.common import merge
+from jet_bridge_base.utils.common import merge, get_set_first
 from jet_bridge_base.utils.db_types import sql_to_map_type, sql_to_db_type
 from jet_bridge_base.views.base.api import APIView
 
 
+def is_column_optional(column):
+    return column.autoincrement or column.default or column.server_default or column.nullable
+
+
 def map_column_default(column):
     if column.server_default is not None:
         if hasattr(column.server_default, 'arg') and isinstance(column.server_default.arg, TextClause):
@@ -21,6 +26,10 @@ def map_column_default(column):
                 return {
                     'default_type': 'datetime_now'
                 }
+            elif value.lower() == 'uuid_generate_v4()':
+                return {
+                    'default_type': 'uuid'
+                }
             elif value.lower() == 'true':
                 return {
                     'default_type': 'value',
@@ -75,13 +84,17 @@ def map_column(column, editable):
         if not table_primary_key or foreign_key.column.name != table_primary_key:
             params['custom_primary_key'] = foreign_key.column.name
 
+    if isinstance(column.type, Date):
+        params['date'] = True
+        params['time'] = False
+
     if isinstance(column.type, Enum):
         params['options'] = map(lambda x: {'name': x, 'value': x}, column.type.enums)
 
     if isinstance(column.type, String):
         params['length'] = column.type.length
 
-    optional = column.autoincrement or column.default or column.server_default or column.nullable
+    optional = is_column_optional(column)
 
     result = {
         'name': column.name,
@@ -104,6 +117,21 @@ def map_column(column, editable):
     return result
 
 
+def map_relationship(relationship):
+    local_field = get_set_first(relationship.local_columns)
+    related_field = get_set_first(relationship.remote_side)
+
+    result = {
+        'name': relationship.key,
+        'direction': 'ONETOMANY',
+        'local_field': local_field.name,
+        'related_model': relationship.target.name,
+        'related_field': related_field.name
+    }
+
+    return result
+
+
 # def map_relation(relation):
 #     field = None
 #
@@ -156,9 +184,11 @@ def map_column(column, editable):
 #
 #     return result
 
-def map_table(cls, hidden, non_editable):
+def map_table(cls, hidden):
     mapper = inspect(cls)
     name = mapper.selectable.name
+    primary_key = mapper.primary_key[0]
+    non_editable = []
 
     from jet_bridge_base.configuration import configuration
     additional = configuration.get_model_description(name)
@@ -167,9 +197,10 @@ def map_table(cls, hidden, non_editable):
         'model': name,
         'db_table': name,
         'fields': list(map(lambda x: map_column(x, x.name not in non_editable), mapper.columns)),
+        'relations': list(map(lambda x: map_relationship(x), filter(lambda x: x.direction == ONETOMANY, mapper.relationships))),
         'hidden': name in hidden or name in configuration.get_hidden_model_description(),
         # 'relations': table_relations(mapper) + table_m2m_relations(mapper),
-        'primary_key_field': mapper.primary_key[0].name
+        'primary_key_field': primary_key.name if primary_key is not None else None
     }
 
     if additional:
@@ -183,11 +214,10 @@ class ModelDescriptionView(APIView):
     permission_classes = (HasProjectPermissions,)
 
     def get_queryset(self, request):
-        non_editable = ['id']
         hidden = ['__jet__token']
         MappedBase = get_mapped_base(request)
 
-        return list(map(lambda x: map_table(x, hidden, non_editable), MappedBase.classes))
+        return list(map(lambda x: map_table(x, hidden), MappedBase.classes))
 
     def get(self, request, *args, **kwargs):
         queryset = self.get_queryset(request)
